@@ -2,6 +2,7 @@
 
 import argparse
 import os.path as osp
+import time
 
 import skrobot
 from skrobot.models.urdf import RobotModelFromURDF
@@ -12,7 +13,7 @@ def main():
     parser.add_argument('input_urdfpath', type=str, help='Input URDF path')
     parser.add_argument(
         '--viewer', type=str,
-        choices=['trimesh', 'pyrender'], default='trimesh',
+        choices=['trimesh', 'pyrender'], default='pyrender',
         help='Choose the viewer type: trimesh or pyrender')
     parser.add_argument(
         '--interactive', '-i',
@@ -22,13 +23,13 @@ def main():
     args = parser.parse_args()
 
     if args.viewer == 'trimesh':
-        viewer = skrobot.viewers.TrimeshSceneViewer()
+        viewer = skrobot.viewers.TrimeshSceneViewer(update_interval=0.1)
     elif args.viewer == 'pyrender':
-        viewer = skrobot.viewers.PyrenderViewer()
+        viewer = skrobot.viewers.PyrenderViewer(update_interval=0.1)
     robot_model = RobotModelFromURDF(
         urdf_file=osp.abspath(args.input_urdfpath))
     viewer.add(robot_model)
-    viewer._init_and_start_app()
+    viewer.show()
     if args.interactive:
         try:
             import IPython
@@ -36,6 +37,11 @@ def main():
             print("IPython is not installed. {}".format(e))
             return
         IPython.embed()
+    else:
+        while viewer.is_active:
+            viewer.redraw()
+            time.sleep(0.1)
+        viewer.close()
 
 
 if __name__ == '__main__':
