@@ -1,16 +1,44 @@
 from __future__ import division
 
 import collections
+import os
+import platform
 import threading
 
 import numpy as np
 import pyglet
 from pyglet import compat_platform
+
+
+# WSL2 Ubuntu 20.04 specific fix for pyrender
+# Check if running in WSL2 environment
+if platform.system() == 'Linux':
+    # Check for WSL-specific indicators
+    if os.path.exists('/proc/version'):
+        try:
+            with open('/proc/version', 'r') as f:
+                version_info = f.read().lower()
+        except (OSError, IOError, PermissionError):
+            version_info = ""
+        if 'microsoft' in version_info or 'wsl' in version_info:
+            # Check Ubuntu version
+            if os.path.exists('/etc/os-release'):
+                try:
+                    with open('/etc/os-release', 'r') as f:
+                        os_info = f.read()
+                except (OSError, IOError, PermissionError):
+                    os_info = ""
+                if '20.04' in os_info:
+                    # Set PYOPENGL_PLATFORM to GLX for WSL2 Ubuntu 20.04
+                    # This ensures proper rendering with X11 forwarding
+                    if 'PYOPENGL_PLATFORM' not in os.environ:
+                        os.environ['PYOPENGL_PLATFORM'] = 'glx'
+
 import pyrender
 from pyrender.trackball import Trackball
 import trimesh
-from trimesh.scene import cameras
 from trimesh import transformations
+from trimesh.scene import cameras
 
 from skrobot.coordinates import Coordinates
 
@@ -66,6 +94,7 @@ class PyrenderViewer(pyrender.Viewer):
 
         self._redraw = True
 
+        refresh_rate = 1.0 / update_interval
         self._kwargs = dict(
             scene=pyrender.Scene(),
             viewport_size=resolution,
@@ -73,7 +102,7 @@ class PyrenderViewer(pyrender.Viewer):
             use_raymond_lighting=True,
             auto_start=False,
             render_flags=render_flags,
-            refresh_rate=update_interval,
+            refresh_rate=refresh_rate,
         )
         super(PyrenderViewer, self).__init__(**self._kwargs)
         self.viewer_flags['window_title'] = 'scikit-robot PyrenderViewer'
@@ -133,7 +162,7 @@ class PyrenderViewer(pyrender.Viewer):
                                              width=self._viewport_size[0],
                                              height=self._viewport_size[1])
                 break
-            except pyglet.window.NoSuchConfigException:
+            except (pyglet.window.NoSuchConfigException, pyglet.gl.ContextException):
                 pass
             except pyglet.canvas.xlib.NoSuchDisplayException:
                 print('No display found. Viewer is disabled.')
