@@ -78,6 +78,7 @@ class TrimeshSceneViewer(trimesh.viewer.SceneViewer):
         self._links = collections.OrderedDict()
 
         self._redraw = True
+        self._is_active = False
         pyglet.clock.schedule_interval(self.on_update, update_interval)
 
         self.scene = trimesh.Scene()
@@ -108,10 +109,12 @@ class TrimeshSceneViewer(trimesh.viewer.SceneViewer):
         self.set_camera([np.deg2rad(45), -np.deg2rad(0), np.deg2rad(135)])
         if compat_platform == 'darwin':
             super(TrimeshSceneViewer, self).__init__(**self._kwargs)
+            self._is_active = True
             init_loop = 30
             for _ in range(init_loop):
                 _redraw_all_windows()
         else:
+            self._is_active = True
             self.thread = threading.Thread(target=self._init_and_start_app)
             self.thread.daemon = True  # terminate when main thread exit
             self.thread.start()
@@ -120,11 +123,14 @@ class TrimeshSceneViewer(trimesh.viewer.SceneViewer):
         with self.lock:
             try:
                 super(TrimeshSceneViewer, self).__init__(**self._kwargs)
+                self._is_active = True
             except pyglet.canvas.xlib.NoSuchDisplayException:
                 print('No display found. Viewer is disabled.')
                 self.has_exit = True
+                self._is_active = False
                 return
         pyglet.app.run()
+        self._is_active = False
 
     def redraw(self):
         self._redraw = True
@@ -259,3 +265,13 @@ class TrimeshSceneViewer(trimesh.viewer.SceneViewer):
         self.dispatch_event('on_draw')
         self.flip()
         return super(TrimeshSceneViewer, self).save_image(file_obj)
+
+    def on_close(self):
+        """Handle window close event by setting is_active to False."""
+        self._is_active = False
+        super(TrimeshSceneViewer, self).on_close()
+
+    @property
+    def is_active(self):
+        """bool : `True` if the viewer is active, or `False` if it has been closed."""
+        return self._is_active
